use i18n::{message, message_ids::MessageId};
use library::{context::Context, model::response::{ResErr, ResResult}, social::wechat::{WeChatAccessToken, WECHAT_SOCIAL}};


pub async fn get_wechat_access_token(context: Context) -> ResResult<WeChatAccessToken> {
    let lang_tag = context.get_lang_tag();
    let access_token = match WECHAT_SOCIAL.get_access_token().await {
        Ok(access_token) => access_token,
        Err(err) => {
            tracing::error!("获取微信access_token失败,err:{}", err);
            return Err(ResErr::service(message!(lang_tag, MessageId::FailedGetWxAaccessToken)));
        }
    };
    Ok(access_token)
}